---
 libavcodec/x86/ac3dsp.asm              |    4 +-
 libavcodec/x86/ac3dsp_mmx.c            |    4 +-
 libavcodec/x86/dsputil_yasm.asm        |    8 ++--
 libavcodec/x86/dsputilenc_mmx.c        |    6 +-
 libavcodec/x86/dsputilenc_yasm.asm     |    2 +-
 libavcodec/x86/h264_chromamc.asm       |   14 +++---
 libavcodec/x86/h264_chromamc_10bit.asm |    4 +-
 libavcodec/x86/h264_deblock.asm        |   20 ++++----
 libavcodec/x86/h264_deblock_10bit.asm  |    4 +-
 libavcodec/x86/h264_idct.asm           |   46 +++++++++--------
 libavcodec/x86/h264_idct_10bit.asm     |    2 +-
 libavcodec/x86/h264_intrapred.asm      |   26 +++++-----
 libavcodec/x86/h264_intrapred_init.c   |   40 +++++++-------
 libavcodec/x86/h264_weight.asm         |   12 ++--
 libavcodec/x86/pngdsp-init.c           |    6 +-
 libavcodec/x86/pngdsp.asm              |    2 +-
 libavcodec/x86/rv34dsp.asm             |    6 +-
 libavcodec/x86/rv34dsp_init.c          |   10 ++--
 libavcodec/x86/rv40dsp.asm             |    4 +-
 libavcodec/x86/rv40dsp_init.c          |   30 ++++++------
 libavcodec/x86/vc1dsp_mmx.c            |   10 ++--
 libavcodec/x86/vc1dsp_yasm.asm         |   10 ++--
 libavcodec/x86/vp3dsp.asm              |    4 +-
 libavcodec/x86/vp3dsp_init.c           |   16 +++---
 libavcodec/x86/vp8dsp-init.c           |   86 ++++++++++++++++----------------
 libavcodec/x86/vp8dsp.asm              |   30 ++++++------
 libavutil/x86/x86inc.asm               |    6 +-
 libavutil/x86/x86util.asm              |    2 +-
 libswscale/x86/output.asm              |    4 +-
 libswscale/x86/swscale.c               |    8 ++--
 30 files changed, 215 insertions(+), 211 deletions(-)

diff --git a/libavcodec/x86/ac3dsp.asm b/libavcodec/x86/ac3dsp.asm
index 5b38cff..c4b0be6 100644
--- a/libavcodec/x86/ac3dsp.asm
+++ b/libavcodec/x86/ac3dsp.asm
@@ -100,7 +100,7 @@ AC3_EXPONENT_MIN sse2
     por         %1, %2
     pshuflw     %2, %1, q0001
     por         %1, %2
-%elif cpuflag(mmx2)
+%elif cpuflag(mmxext)
     pshufw      %2, %1, q0032
     por         %1, %2
     pshufw      %2, %1, q0001
@@ -156,7 +156,7 @@ cglobal ac3_max_msb_abs_int16, 2,2,5, src, len
 INIT_MMX mmx
 %define ABS2 ABS2_MMX
 AC3_MAX_MSB_ABS_INT16 or_abs
-INIT_MMX mmx2
+INIT_MMX mmxext
 %define ABS2 ABS2_MMXEXT
 AC3_MAX_MSB_ABS_INT16 min_max
 INIT_XMM sse2
diff --git a/libavcodec/x86/ac3dsp_mmx.c b/libavcodec/x86/ac3dsp_mmx.c
index 0ac8685..cac51cb 100644
--- a/libavcodec/x86/ac3dsp_mmx.c
+++ b/libavcodec/x86/ac3dsp_mmx.c
@@ -28,7 +28,7 @@ extern void ff_ac3_exponent_min_mmxext(uint8_t *exp, int 
num_reuse_blocks, int n
 extern void ff_ac3_exponent_min_sse2  (uint8_t *exp, int num_reuse_blocks, int 
nb_coefs);
 
 extern int ff_ac3_max_msb_abs_int16_mmx  (const int16_t *src, int len);
-extern int ff_ac3_max_msb_abs_int16_mmx2 (const int16_t *src, int len);
+extern int ff_ac3_max_msb_abs_int16_mmxext(const int16_t *src, int len);
 extern int ff_ac3_max_msb_abs_int16_sse2 (const int16_t *src, int len);
 extern int ff_ac3_max_msb_abs_int16_ssse3(const int16_t *src, int len);
 
@@ -67,7 +67,7 @@ av_cold void ff_ac3dsp_init_x86(AC3DSPContext *c, int 
bit_exact)
     }
     if (mm_flags & AV_CPU_FLAG_MMXEXT && HAVE_MMXEXT) {
         c->ac3_exponent_min = ff_ac3_exponent_min_mmxext;
-        c->ac3_max_msb_abs_int16 = ff_ac3_max_msb_abs_int16_mmx2;
+        c->ac3_max_msb_abs_int16 = ff_ac3_max_msb_abs_int16_mmxext;
     }
     if (mm_flags & AV_CPU_FLAG_SSE && HAVE_SSE) {
         c->float_to_fixed24 = ff_float_to_fixed24_sse;
diff --git a/libavcodec/x86/dsputil_yasm.asm b/libavcodec/x86/dsputil_yasm.asm
index 70a0aa1..64c4e32 100644
--- a/libavcodec/x86/dsputil_yasm.asm
+++ b/libavcodec/x86/dsputil_yasm.asm
@@ -109,7 +109,7 @@ cglobal scalarproduct_and_madd_int16_%1, 4,4,8, v1, v2, v3, 
order, mul
 %endmacro
 
 INIT_MMX
-SCALARPRODUCT mmx2
+SCALARPRODUCT mmxext
 INIT_XMM
 SCALARPRODUCT sse2
 
@@ -328,8 +328,8 @@ APPLY_WINDOW_INT16 ssse3_atom, 0, 1
 APPLY_WINDOW_INT16 ssse3,      0, 1
 
 
-; void add_hfyu_median_prediction_mmx2(uint8_t *dst, const uint8_t *top, const 
uint8_t *diff, int w, int *left, int *left_top)
-cglobal add_hfyu_median_prediction_mmx2, 6,6,0, dst, top, diff, w, left, 
left_top
+; void add_hfyu_median_prediction_mmxext(uint8_t *dst, const uint8_t *top, 
const uint8_t *diff, int w, int *left, int *left_top)
+cglobal add_hfyu_median_prediction_mmxext, 6,6,0, dst, top, diff, w, left, 
left_top
     movq    mm0, [topq]
     movq    mm2, mm0
     movd    mm4, [left_topq]
@@ -799,7 +799,7 @@ ALIGN 128
     mov        valh, vall
 %if %1 >= 8
     movd        mm0, vald
-%if cpuflag(mmx2)
+%if cpuflag(mmxext)
     pshufw      mm0, mm0, 0
 %else ; mmx
     punpcklwd   mm0, mm0
diff --git a/libavcodec/x86/dsputilenc_mmx.c b/libavcodec/x86/dsputilenc_mmx.c
index 6cffe68..f94f2d2 100644
--- a/libavcodec/x86/dsputilenc_mmx.c
+++ b/libavcodec/x86/dsputilenc_mmx.c
@@ -939,7 +939,7 @@ int ff_hadamard8_diff16_##cpu(void *s, uint8_t *src1, 
uint8_t *src2, \
                               int stride, int h);
 
 hadamard_func(mmx)
-hadamard_func(mmx2)
+hadamard_func(mmxext)
 hadamard_func(sse2)
 hadamard_func(ssse3)
 
@@ -1154,8 +1154,8 @@ void ff_dsputilenc_init_mmx(DSPContext* c, AVCodecContext 
*avctx)
 
         if (mm_flags & AV_CPU_FLAG_MMXEXT) {
 #if HAVE_YASM
-            c->hadamard8_diff[0]= ff_hadamard8_diff16_mmx2;
-            c->hadamard8_diff[1]= ff_hadamard8_diff_mmx2;
+            c->hadamard8_diff[0] = ff_hadamard8_diff16_mmxext;
+            c->hadamard8_diff[1] = ff_hadamard8_diff_mmxext;
 #endif
             c->sum_abs_dctelem = sum_abs_dctelem_mmxext;
             c->vsad[4]         = vsad_intra16_mmxext;
diff --git a/libavcodec/x86/dsputilenc_yasm.asm 
b/libavcodec/x86/dsputilenc_yasm.asm
index c6ed2da..6e4e1ec 100644
--- a/libavcodec/x86/dsputilenc_yasm.asm
+++ b/libavcodec/x86/dsputilenc_yasm.asm
@@ -266,7 +266,7 @@ HADAMARD8_DIFF_MMX mmx
 
 %define ABS1 ABS1_MMXEXT
 %define HSUM HSUM_MMXEXT
-HADAMARD8_DIFF_MMX mmx2
+HADAMARD8_DIFF_MMX mmxext
 
 INIT_XMM
 %define ABS2 ABS2_MMXEXT
diff --git a/libavcodec/x86/h264_chromamc.asm b/libavcodec/x86/h264_chromamc.asm
index 64a4efe..7b39c29 100644
--- a/libavcodec/x86/h264_chromamc.asm
+++ b/libavcodec/x86/h264_chromamc.asm
@@ -443,17 +443,17 @@ chroma_mc8_mmx_func put, vc1,  mmx_nornd
 chroma_mc8_mmx_func put, rv40, mmx
 chroma_mc4_mmx_func put, h264, mmx
 chroma_mc4_mmx_func put, rv40, mmx
-chroma_mc2_mmx_func put, h264, mmx2
+chroma_mc2_mmx_func put, h264, mmxext
 
 %define CHROMAMC_AVG  DIRECT_AVG
 %define CHROMAMC_AVG4 COPY_AVG
 %define PAVG          pavgb
-chroma_mc8_mmx_func avg, h264, mmx2_rnd
-chroma_mc8_mmx_func avg, vc1,  mmx2_nornd
-chroma_mc8_mmx_func avg, rv40, mmx2
-chroma_mc4_mmx_func avg, h264, mmx2
-chroma_mc4_mmx_func avg, rv40, mmx2
-chroma_mc2_mmx_func avg, h264, mmx2
+chroma_mc8_mmx_func avg, h264, mmxext_rnd
+chroma_mc8_mmx_func avg, vc1,  mmxext_nornd
+chroma_mc8_mmx_func avg, rv40, mmxext
+chroma_mc4_mmx_func avg, h264, mmxext
+chroma_mc4_mmx_func avg, rv40, mmxext
+chroma_mc2_mmx_func avg, h264, mmxext
 
 %define PAVG          pavgusb
 chroma_mc8_mmx_func avg, h264, 3dnow_rnd
diff --git a/libavcodec/x86/h264_chromamc_10bit.asm 
b/libavcodec/x86/h264_chromamc_10bit.asm
index 370c7b5..d6e7372 100644
--- a/libavcodec/x86/h264_chromamc_10bit.asm
+++ b/libavcodec/x86/h264_chromamc_10bit.asm
@@ -256,7 +256,7 @@ CHROMA_MC8 put
 INIT_XMM avx
 CHROMA_MC8 put
 %endif
-INIT_MMX mmx2
+INIT_MMX mmxext
 CHROMA_MC4 put
 CHROMA_MC2 put
 
@@ -268,6 +268,6 @@ CHROMA_MC8 avg
 INIT_XMM avx
 CHROMA_MC8 avg
 %endif
-INIT_MMX mmx2
+INIT_MMX mmxext
 CHROMA_MC4 avg
 CHROMA_MC2 avg
diff --git a/libavcodec/x86/h264_deblock.asm b/libavcodec/x86/h264_deblock.asm
index 940a8f7..45cb7f6 100644
--- a/libavcodec/x86/h264_deblock.asm
+++ b/libavcodec/x86/h264_deblock.asm
@@ -505,7 +505,7 @@ cglobal deblock_h_luma_8, 0,5
     RET
 %endmacro ; DEBLOCK_LUMA
 
-INIT_MMX mmx2
+INIT_MMX mmxext
 DEBLOCK_LUMA v8, 8
 INIT_XMM sse2
 DEBLOCK_LUMA v, 16
@@ -784,11 +784,11 @@ DEBLOCK_LUMA_INTRA v
 INIT_XMM avx
 DEBLOCK_LUMA_INTRA v
 %if ARCH_X86_64 == 0
-INIT_MMX mmx2
+INIT_MMX mmxext
 DEBLOCK_LUMA_INTRA v8
 %endif
 
-INIT_MMX mmx2
+INIT_MMX mmxext
 
 %macro CHROMA_V_START 0
     dec    r2d      ; alpha-1
@@ -819,7 +819,7 @@ cglobal deblock_v_chroma_8, 5,6
     movq  m1, [t5+r1]
     movq  m2, [r0]
     movq  m3, [r0+r1]
-    call ff_chroma_inter_body_mmx2
+    call ff_chroma_inter_body_mmxext
     movq  [t5+r1], m1
     movq  [r0], m2
     RET
@@ -843,7 +843,7 @@ cglobal deblock_h_chroma_8, 5,7
     TRANSPOSE4x8_LOAD  bw, wd, dq, PASS8ROWS(t5, r0, r1, t6)
     movq  buf0, m0
     movq  buf1, m3
-    call ff_chroma_inter_body_mmx2
+    call ff_chroma_inter_body_mmxext
     movq  m0, buf0
     movq  m3, buf1
     TRANSPOSE8x4B_STORE PASS8ROWS(t5, r0, r1, t6)
@@ -853,7 +853,7 @@ cglobal deblock_h_chroma_8, 5,7
     RET
 
 ALIGN 16
-ff_chroma_inter_body_mmx2:
+ff_chroma_inter_body_mmxext:
     LOAD_MASK  r2d, r3d
     movd       m6, [r4] ; tc0
     punpcklbw  m6, m6
@@ -886,7 +886,7 @@ cglobal deblock_v_chroma_intra_8, 4,5
     movq  m1, [t5+r1]
     movq  m2, [r0]
     movq  m3, [r0+r1]
-    call ff_chroma_intra_body_mmx2
+    call ff_chroma_intra_body_mmxext
     movq  [t5+r1], m1
     movq  [r0], m2
     RET
@@ -897,12 +897,12 @@ cglobal deblock_v_chroma_intra_8, 4,5
 cglobal deblock_h_chroma_intra_8, 4,6
     CHROMA_H_START
     TRANSPOSE4x8_LOAD  bw, wd, dq, PASS8ROWS(t5, r0, r1, t6)
-    call ff_chroma_intra_body_mmx2
+    call ff_chroma_intra_body_mmxext
     TRANSPOSE8x4B_STORE PASS8ROWS(t5, r0, r1, t6)
     RET
 
 ALIGN 16
-ff_chroma_intra_body_mmx2:
+ff_chroma_intra_body_mmxext:
     LOAD_MASK r2d, r3d
     movq   m5, m1
     movq   m6, m2
@@ -1026,7 +1026,7 @@ ff_chroma_intra_body_mmx2:
     jl %%.b_idx_loop
 %endmacro
 
-INIT_MMX mmx2
+INIT_MMX mmxext
 cglobal h264_loop_filter_strength, 9, 9, 0, bs, nnz, ref, mv, bidir, edges, \
                                             step, mask_mv0, mask_mv1, field
 %define b_idxq bidirq
diff --git a/libavcodec/x86/h264_deblock_10bit.asm 
b/libavcodec/x86/h264_deblock_10bit.asm
index ba2f914..123d8c4 100644
--- a/libavcodec/x86/h264_deblock_10bit.asm
+++ b/libavcodec/x86/h264_deblock_10bit.asm
@@ -792,7 +792,7 @@ cglobal deblock_h_luma_intra_10, 4,7,8*(mmsize/16)
 %endmacro
 
 %if ARCH_X86_64 == 0
-INIT_MMX mmx2
+INIT_MMX mmxext
 DEBLOCK_LUMA
 DEBLOCK_LUMA_INTRA
 INIT_XMM sse2
@@ -907,7 +907,7 @@ cglobal deblock_v_chroma_intra_10, 
4,6-(mmsize/16),8*(mmsize/16)
 %endmacro
 
 %if ARCH_X86_64 == 0
-INIT_MMX mmx2
+INIT_MMX mmxext
 DEBLOCK_CHROMA
 %endif
 INIT_XMM sse2
diff --git a/libavcodec/x86/h264_idct.asm b/libavcodec/x86/h264_idct.asm
index 0fe5176..56d40eb 100644
--- a/libavcodec/x86/h264_idct.asm
+++ b/libavcodec/x86/h264_idct.asm
@@ -287,14 +287,14 @@ cglobal h264_idct8_add_8_sse2, 3, 4, 10
 %endmacro
 
 INIT_MMX
-; ff_h264_idct_dc_add_mmx2(uint8_t *dst, int16_t *block, int stride)
-cglobal h264_idct_dc_add_8_mmx2, 3, 3, 0
+; ff_h264_idct_dc_add_mmxext(uint8_t *dst, int16_t *block, int stride)
+cglobal h264_idct_dc_add_8_mmxext, 3, 3, 0
     DC_ADD_MMXEXT_INIT r1, r2
     DC_ADD_MMXEXT_OP movh, r0, r2, r1
     RET
 
-; ff_h264_idct8_dc_add_mmx2(uint8_t *dst, int16_t *block, int stride)
-cglobal h264_idct8_dc_add_8_mmx2, 3, 3, 0
+; ff_h264_idct8_dc_add_mmxext(uint8_t *dst, int16_t *block, int stride)
+cglobal h264_idct8_dc_add_8_mmxext, 3, 3, 0
     DC_ADD_MMXEXT_INIT r1, r2
     DC_ADD_MMXEXT_OP mova, r0, r2, r1
     lea          r0, [r0+r2*4]
@@ -355,9 +355,9 @@ cglobal h264_idct8_add4_8_mmx, 5, 7 + npicregs, 0, dst, 
block_offset, block, str
     ADD         rsp, pad
     RET
 
-; ff_h264_idct_add16_mmx2(uint8_t *dst, const int *block_offset,
-;                         DCTELEM *block, int stride, const uint8_t nnzc[6*8])
-cglobal h264_idct_add16_8_mmx2, 5, 8 + npicregs, 0, dst1, block_offset, block, 
stride, nnzc, cntr, coeff, dst2, picreg
+; ff_h264_idct_add16_mmxext(uint8_t *dst, const int *block_offset,
+;                           DCTELEM *block, int stride, const uint8_t 
nnzc[6*8])
+cglobal h264_idct_add16_8_mmxext, 5, 8 + npicregs, 0, dst1, block_offset, 
block, stride, nnzc, cntr, coeff, dst2, picreg
     xor          r5, r5
 %ifdef PIC
     lea     picregq, [scan8_mem]
@@ -422,9 +422,10 @@ cglobal h264_idct_add16intra_8_mmx, 5, 7 + npicregs, 0, 
dst, block_offset, block
     jl .nextblock
     REP_RET
 
-; ff_h264_idct_add16intra_mmx2(uint8_t *dst, const int *block_offset,
-;                              DCTELEM *block, int stride, const uint8_t 
nnzc[6*8])
-cglobal h264_idct_add16intra_8_mmx2, 5, 8 + npicregs, 0, dst1, block_offset, 
block, stride, nnzc, cntr, coeff, dst2, picreg
+; ff_h264_idct_add16intra_mmxext(uint8_t *dst, const int *block_offset,
+;                                DCTELEM *block, int stride,
+;                                const uint8_t nnzc[6*8])
+cglobal h264_idct_add16intra_8_mmxext, 5, 8 + npicregs, 0, dst1, block_offset, 
block, stride, nnzc, cntr, coeff, dst2, picreg
     xor          r5, r5
 %ifdef PIC
     lea     picregq, [scan8_mem]
@@ -464,9 +465,10 @@ cglobal h264_idct_add16intra_8_mmx2, 5, 8 + npicregs, 0, 
dst1, block_offset, blo
     jl .nextblock
     REP_RET
 
-; ff_h264_idct8_add4_mmx2(uint8_t *dst, const int *block_offset,
-;                         DCTELEM *block, int stride, const uint8_t nnzc[6*8])
-cglobal h264_idct8_add4_8_mmx2, 5, 8 + npicregs, 0, dst1, block_offset, block, 
stride, nnzc, cntr, coeff, dst2, picreg
+; ff_h264_idct8_add4_mmxext(uint8_t *dst, const int *block_offset,
+;                           DCTELEM *block, int stride,
+;                           const uint8_t nnzc[6*8])
+cglobal h264_idct8_add4_8_mmxext, 5, 8 + npicregs, 0, dst1, block_offset, 
block, stride, nnzc, cntr, coeff, dst2, picreg
     %assign pad 128+4-(stack_offset&7)
     SUB         rsp, pad
 
@@ -621,7 +623,7 @@ cglobal h264_idct_add8_8_mmx, 5, 8 + npicregs, 0, dst1, 
block_offset, block, str
     call         h264_idct_add8_mmx_plane
     RET
 
-h264_idct_add8_mmx2_plane
+h264_idct_add8_mmxext_plane
 .nextblock
     movzx        r6, byte [scan8+r5]
     movzx        r6, byte [r4+r6]
@@ -662,9 +664,9 @@ h264_idct_add8_mmx2_plane
     jnz .nextblock
     rep ret
 
-; ff_h264_idct_add8_mmx2(uint8_t **dest, const int *block_offset,
-;                        DCTELEM *block, int stride, const uint8_t nnzc[6*8])
-cglobal h264_idct_add8_8_mmx2, 5, 8 + npicregs, 0, dst1, block_offset, block, 
stride, nnzc, cntr, coeff, dst2, picreg
+; ff_h264_idct_add8_mmxext(uint8_t **dest, const int *block_offset,
+;                          DCTELEM *block, int stride, const uint8_t nnzc[6*8])
+cglobal h264_idct_add8_8_mmxext, 5, 8 + npicregs, 0, dst1, block_offset, 
block, stride, nnzc, cntr, coeff, dst2, picreg
     mov          r5, 16
     add          r2, 512
 %if ARCH_X86_64
@@ -673,7 +675,7 @@ cglobal h264_idct_add8_8_mmx2, 5, 8 + npicregs, 0, dst1, 
block_offset, block, st
 %ifdef PIC
     lea     picregq, [scan8_mem]
 %endif
-    call h264_idct_add8_mmx2_plane
+    call h264_idct_add8_mmxext_plane
     mov          r5, 32
     add          r2, 384
 %if ARCH_X86_64
@@ -681,12 +683,12 @@ cglobal h264_idct_add8_8_mmx2, 5, 8 + npicregs, 0, dst1, 
block_offset, block, st
 %else
     add        r0mp, gprsize
 %endif
-    call h264_idct_add8_mmx2_plane
+    call h264_idct_add8_mmxext_plane
     RET
 
 INIT_MMX
 ; r0 = uint8_t *dst, r2 = int16_t *block, r3 = int stride, r6=clobbered
-h264_idct_dc_add8_mmx2:
+h264_idct_dc_add8_mmxext:
     movd         m0, [r2   ]          ;  0 0 X D
     punpcklwd    m0, [r2+32]          ;  x X d D
     paddsw       m0, [pw_32]
@@ -780,7 +782,7 @@ cglobal h264_idct_add16_8_sse2, 5, 5 + ARCH_X86_64, 8
 %else
     add         r0, r0m
 %endif
-    call        h264_idct_dc_add8_mmx2
+    call        h264_idct_dc_add8_mmxext
 .cycle%1end
 %if %1 < 7
     add         r2, 64
@@ -829,7 +831,7 @@ cglobal h264_idct_add16intra_8_sse2, 5, 7 + ARCH_X86_64, 8
     mov         r0, [r0]
     add         r0, dword [r1+(%1&1)*8+64*(1+(%1>>1))]
 %endif
-    call        h264_idct_dc_add8_mmx2
+    call        h264_idct_dc_add8_mmxext
 .cycle%1end
 %if %1 == 1
     add         r2, 384+64
diff --git a/libavcodec/x86/h264_idct_10bit.asm 
b/libavcodec/x86/h264_idct_10bit.asm
index 2aab986..a619bcc 100644
--- a/libavcodec/x86/h264_idct_10bit.asm
+++ b/libavcodec/x86/h264_idct_10bit.asm
@@ -185,7 +185,7 @@ IDCT_ADD16_10
     mova [%1+%3  ], m4
 %endmacro
 
-INIT_MMX mmx2
+INIT_MMX mmxext
 cglobal h264_idct_dc_add_10,3,3
     movd      m0, [r1]
     paddd     m0, [pd_32]
diff --git a/libavcodec/x86/h264_intrapred.asm 
b/libavcodec/x86/h264_intrapred.asm
index 50a615b..9d2e5c7 100644
--- a/libavcodec/x86/h264_intrapred.asm
+++ b/libavcodec/x86/h264_intrapred.asm
@@ -119,7 +119,7 @@ cglobal pred16x16_horizontal, 2,3
 
 INIT_MMX mmx
 PRED16x16_H
-INIT_MMX mmx2
+INIT_MMX mmxext
 PRED16x16_H
 INIT_XMM ssse3
 PRED16x16_H
@@ -180,7 +180,7 @@ cglobal pred16x16_dc, 2,7
     REP_RET
 %endmacro
 
-INIT_MMX mmx2
+INIT_MMX mmxext
 PRED16x16_DC
 INIT_XMM sse2
 PRED16x16_DC
@@ -230,7 +230,7 @@ cglobal pred16x16_tm_vp8, 2,5
 
 INIT_MMX mmx
 PRED16x16_TM_MMX
-INIT_MMX mmx2
+INIT_MMX mmxext
 PRED16x16_TM_MMX
 INIT_MMX
 
@@ -310,14 +310,14 @@ cglobal pred16x16_plane_%1, 2,9,7
     movhlps      m1, m0
 %endif
     paddw        m0, m1
-%if cpuflag(mmx2)
+%if cpuflag(mmxext)
     PSHUFLW      m1, m0, 0xE
 %elif cpuflag(mmx)
     mova         m1, m0
     psrlq        m1, 32
 %endif
     paddw        m0, m1
-%if cpuflag(mmx2)
+%if cpuflag(mmxext)
     PSHUFLW      m1, m0, 0x1
 %elif cpuflag(mmx)
     mova         m1, m0
@@ -537,7 +537,7 @@ INIT_MMX mmx
 H264_PRED16x16_PLANE h264
 H264_PRED16x16_PLANE rv40
 H264_PRED16x16_PLANE svq3
-INIT_MMX mmx2
+INIT_MMX mmxext
 H264_PRED16x16_PLANE h264
 H264_PRED16x16_PLANE rv40
 H264_PRED16x16_PLANE svq3
@@ -584,7 +584,7 @@ cglobal pred8x8_plane, 2,9,7
     paddw        m0, m1
 
 %if notcpuflag(ssse3)
-%if cpuflag(mmx2)
+%if cpuflag(mmxext)
     PSHUFLW      m1, m0, 0xE
 %elif cpuflag(mmx)
     mova         m1, m0
@@ -593,7 +593,7 @@ cglobal pred8x8_plane, 2,9,7
     paddw        m0, m1
 %endif ; !ssse3
 
-%if cpuflag(mmx2)
+%if cpuflag(mmxext)
     PSHUFLW      m1, m0, 0x1
 %elif cpuflag(mmx)
     mova         m1, m0
@@ -718,7 +718,7 @@ ALIGN 16
 
 INIT_MMX mmx
 H264_PRED8x8_PLANE
-INIT_MMX mmx2
+INIT_MMX mmxext
 H264_PRED8x8_PLANE
 INIT_XMM sse2
 H264_PRED8x8_PLANE
@@ -765,7 +765,7 @@ cglobal pred8x8_horizontal, 2,3
 
 INIT_MMX mmx
 PRED8x8_H
-INIT_MMX mmx2
+INIT_MMX mmxext
 PRED8x8_H
 INIT_MMX ssse3
 PRED8x8_H
@@ -942,7 +942,7 @@ cglobal pred8x8_tm_vp8, 2,6
 
 INIT_MMX mmx
 PRED8x8_TM_MMX
-INIT_MMX mmx2
+INIT_MMX mmxext
 PRED8x8_TM_MMX
 INIT_MMX
 
@@ -2459,7 +2459,7 @@ cglobal pred4x4_tm_vp8, 3,6
     sub       r3d, r4d
     movd      mm2, r1d
     movd      mm4, r3d
-%if cpuflag(mmx2)
+%if cpuflag(mmxext)
     pshufw    mm2, mm2, 0
     pshufw    mm4, mm4, 0
 %else
@@ -2482,7 +2482,7 @@ cglobal pred4x4_tm_vp8, 3,6
 
 INIT_MMX mmx
 PRED4x4_TM_MMX
-INIT_MMX mmx2
+INIT_MMX mmxext
 PRED4x4_TM_MMX
 INIT_MMX
 
diff --git a/libavcodec/x86/h264_intrapred_init.c 
b/libavcodec/x86/h264_intrapred_init.c
index 08c35c7..d82a846 100644
--- a/libavcodec/x86/h264_intrapred_init.c
+++ b/libavcodec/x86/h264_intrapred_init.c
@@ -96,39 +96,39 @@ PRED16x16(horizontal, 10, sse2)
 void ff_pred16x16_vertical_mmx     (uint8_t *src, int stride);
 void ff_pred16x16_vertical_sse     (uint8_t *src, int stride);
 void ff_pred16x16_horizontal_mmx   (uint8_t *src, int stride);
-void ff_pred16x16_horizontal_mmx2  (uint8_t *src, int stride);
+void ff_pred16x16_horizontal_mmxext(uint8_t *src, int stride);
 void ff_pred16x16_horizontal_ssse3 (uint8_t *src, int stride);
-void ff_pred16x16_dc_mmx2          (uint8_t *src, int stride);
+void ff_pred16x16_dc_mmxext        (uint8_t *src, int stride);
 void ff_pred16x16_dc_sse2          (uint8_t *src, int stride);
 void ff_pred16x16_dc_ssse3         (uint8_t *src, int stride);
 void ff_pred16x16_plane_h264_mmx   (uint8_t *src, int stride);
-void ff_pred16x16_plane_h264_mmx2  (uint8_t *src, int stride);
+void ff_pred16x16_plane_h264_mmxext(uint8_t *src, int stride);
 void ff_pred16x16_plane_h264_sse2  (uint8_t *src, int stride);
 void ff_pred16x16_plane_h264_ssse3 (uint8_t *src, int stride);
 void ff_pred16x16_plane_rv40_mmx   (uint8_t *src, int stride);
-void ff_pred16x16_plane_rv40_mmx2  (uint8_t *src, int stride);
+void ff_pred16x16_plane_rv40_mmxext(uint8_t *src, int stride);
 void ff_pred16x16_plane_rv40_sse2  (uint8_t *src, int stride);
 void ff_pred16x16_plane_rv40_ssse3 (uint8_t *src, int stride);
 void ff_pred16x16_plane_svq3_mmx   (uint8_t *src, int stride);
-void ff_pred16x16_plane_svq3_mmx2  (uint8_t *src, int stride);
+void ff_pred16x16_plane_svq3_mmxext(uint8_t *src, int stride);
 void ff_pred16x16_plane_svq3_sse2  (uint8_t *src, int stride);
 void ff_pred16x16_plane_svq3_ssse3 (uint8_t *src, int stride);
 void ff_pred16x16_tm_vp8_mmx       (uint8_t *src, int stride);
-void ff_pred16x16_tm_vp8_mmx2      (uint8_t *src, int stride);
+void ff_pred16x16_tm_vp8_mmxext    (uint8_t *src, int stride);
 void ff_pred16x16_tm_vp8_sse2      (uint8_t *src, int stride);
 void ff_pred8x8_top_dc_mmxext      (uint8_t *src, int stride);
 void ff_pred8x8_dc_rv40_mmxext     (uint8_t *src, int stride);
 void ff_pred8x8_dc_mmxext          (uint8_t *src, int stride);
 void ff_pred8x8_vertical_mmx       (uint8_t *src, int stride);
 void ff_pred8x8_horizontal_mmx     (uint8_t *src, int stride);
-void ff_pred8x8_horizontal_mmx2    (uint8_t *src, int stride);
+void ff_pred8x8_horizontal_mmxext  (uint8_t *src, int stride);
 void ff_pred8x8_horizontal_ssse3   (uint8_t *src, int stride);
 void ff_pred8x8_plane_mmx          (uint8_t *src, int stride);
-void ff_pred8x8_plane_mmx2         (uint8_t *src, int stride);
+void ff_pred8x8_plane_mmxext       (uint8_t *src, int stride);
 void ff_pred8x8_plane_sse2         (uint8_t *src, int stride);
 void ff_pred8x8_plane_ssse3        (uint8_t *src, int stride);
 void ff_pred8x8_tm_vp8_mmx         (uint8_t *src, int stride);
-void ff_pred8x8_tm_vp8_mmx2        (uint8_t *src, int stride);
+void ff_pred8x8_tm_vp8_mmxext      (uint8_t *src, int stride);
 void ff_pred8x8_tm_vp8_sse2        (uint8_t *src, int stride);
 void ff_pred8x8_tm_vp8_ssse3       (uint8_t *src, int stride);
 void ff_pred8x8l_top_dc_mmxext     (uint8_t *src, int has_topleft, int 
has_topright, int stride);
@@ -163,7 +163,7 @@ void ff_pred4x4_vertical_right_mmxext(uint8_t *src, const 
uint8_t *topright, int
 void ff_pred4x4_horizontal_up_mmxext(uint8_t *src, const uint8_t *topright, 
int stride);
 void ff_pred4x4_horizontal_down_mmxext(uint8_t *src, const uint8_t *topright, 
int stride);
 void ff_pred4x4_tm_vp8_mmx         (uint8_t *src, const uint8_t *topright, int 
stride);
-void ff_pred4x4_tm_vp8_mmx2        (uint8_t *src, const uint8_t *topright, int 
stride);
+void ff_pred4x4_tm_vp8_mmxext      (uint8_t *src, const uint8_t *topright, int 
stride);
 void ff_pred4x4_tm_vp8_ssse3       (uint8_t *src, const uint8_t *topright, int 
stride);
 void ff_pred4x4_vertical_vp8_mmxext(uint8_t *src, const uint8_t *topright, int 
stride);
 
@@ -199,10 +199,10 @@ void ff_h264_pred_init_x86(H264PredContext *h, int 
codec_id, const int bit_depth
         }
 
         if (mm_flags & AV_CPU_FLAG_MMXEXT) {
-            h->pred16x16[HOR_PRED8x8            ] = 
ff_pred16x16_horizontal_mmx2;
-            h->pred16x16[DC_PRED8x8             ] = ff_pred16x16_dc_mmx2;
+            h->pred16x16[HOR_PRED8x8            ] = 
ff_pred16x16_horizontal_mmxext;
+            h->pred16x16[DC_PRED8x8             ] = ff_pred16x16_dc_mmxext;
             if (chroma_format_idc == 1)
-                h->pred8x8[HOR_PRED8x8          ] = ff_pred8x8_horizontal_mmx2;
+                h->pred8x8[HOR_PRED8x8          ] = 
ff_pred8x8_horizontal_mmxext;
             h->pred8x8l [TOP_DC_PRED            ] = ff_pred8x8l_top_dc_mmxext;
             h->pred8x8l [DC_PRED                ] = ff_pred8x8l_dc_mmxext;
             h->pred8x8l [HOR_PRED               ] = 
ff_pred8x8l_horizontal_mmxext;
@@ -232,20 +232,20 @@ void ff_h264_pred_init_x86(H264PredContext *h, int 
codec_id, const int bit_depth
                 }
             }
             if (codec_id == CODEC_ID_VP8) {
-                h->pred16x16[PLANE_PRED8x8      ] = ff_pred16x16_tm_vp8_mmx2;
+                h->pred16x16[PLANE_PRED8x8      ] = ff_pred16x16_tm_vp8_mmxext;
                 h->pred8x8  [DC_PRED8x8         ] = ff_pred8x8_dc_rv40_mmxext;
-                h->pred8x8  [PLANE_PRED8x8      ] = ff_pred8x8_tm_vp8_mmx2;
-                h->pred4x4  [TM_VP8_PRED        ] = ff_pred4x4_tm_vp8_mmx2;
+                h->pred8x8  [PLANE_PRED8x8      ] = ff_pred8x8_tm_vp8_mmxext;
+                h->pred4x4  [TM_VP8_PRED        ] = ff_pred4x4_tm_vp8_mmxext;
                 h->pred4x4  [VERT_PRED          ] = 
ff_pred4x4_vertical_vp8_mmxext;
             } else {
                 if (chroma_format_idc == 1)
-                    h->pred8x8  [PLANE_PRED8x8] = ff_pred8x8_plane_mmx2;
+                    h->pred8x8  [PLANE_PRED8x8] = ff_pred8x8_plane_mmxext;
                 if (codec_id == CODEC_ID_SVQ3) {
-                    h->pred16x16[PLANE_PRED8x8  ] = 
ff_pred16x16_plane_svq3_mmx2;
+                    h->pred16x16[PLANE_PRED8x8  ] = 
ff_pred16x16_plane_svq3_mmxext;
                 } else if (codec_id == CODEC_ID_RV40) {
-                    h->pred16x16[PLANE_PRED8x8  ] = 
ff_pred16x16_plane_rv40_mmx2;
+                    h->pred16x16[PLANE_PRED8x8  ] = 
ff_pred16x16_plane_rv40_mmxext;
                 } else {
-                    h->pred16x16[PLANE_PRED8x8  ] = 
ff_pred16x16_plane_h264_mmx2;
+                    h->pred16x16[PLANE_PRED8x8  ] = 
ff_pred16x16_plane_h264_mmxext;
                 }
             }
         }
diff --git a/libavcodec/x86/h264_weight.asm b/libavcodec/x86/h264_weight.asm
index 22ce72d..16757c0 100644
--- a/libavcodec/x86/h264_weight.asm
+++ b/libavcodec/x86/h264_weight.asm
@@ -71,7 +71,7 @@ SECTION .text
 %endmacro
 
 INIT_MMX
-cglobal h264_weight_16_mmx2, 6, 6, 0
+cglobal h264_weight_16_mmxext, 6, 6, 0
     WEIGHT_SETUP
 .nextrow
     WEIGHT_OP 0,  4
@@ -96,7 +96,7 @@ cglobal h264_weight_%1_%3, 6, 6, %2
 %endmacro
 
 INIT_MMX
-WEIGHT_FUNC_MM  8, 0, mmx2
+WEIGHT_FUNC_MM  8, 0, mmxext
 INIT_XMM
 WEIGHT_FUNC_MM 16, 8, sse2
 
@@ -121,7 +121,7 @@ cglobal h264_weight_%1_%3, 6, 6, %2
 %endmacro
 
 INIT_MMX
-WEIGHT_FUNC_HALF_MM 4, 0, mmx2
+WEIGHT_FUNC_HALF_MM 4, 0, mmxext
 INIT_XMM
 WEIGHT_FUNC_HALF_MM 8, 8, sse2
 
@@ -175,7 +175,7 @@ WEIGHT_FUNC_HALF_MM 8, 8, sse2
 %endmacro
 
 INIT_MMX
-cglobal h264_biweight_16_mmx2, 7, 8, 0
+cglobal h264_biweight_16_mmxext, 7, 8, 0
     BIWEIGHT_SETUP
     movifnidn r3d, r3m
 .nextrow
@@ -210,7 +210,7 @@ cglobal h264_biweight_%1_%3, 7, 8, %2
 %endmacro
 
 INIT_MMX
-BIWEIGHT_FUNC_MM  8, 0, mmx2
+BIWEIGHT_FUNC_MM  8, 0, mmxext
 INIT_XMM
 BIWEIGHT_FUNC_MM 16, 8, sse2
 
@@ -239,7 +239,7 @@ cglobal h264_biweight_%1_%3, 7, 8, %2
 %endmacro
 
 INIT_MMX
-BIWEIGHT_FUNC_HALF_MM 4, 0, mmx2
+BIWEIGHT_FUNC_HALF_MM 4, 0, mmxext
 INIT_XMM
 BIWEIGHT_FUNC_HALF_MM 8, 8, sse2
 
diff --git a/libavcodec/x86/pngdsp-init.c b/libavcodec/x86/pngdsp-init.c
index aa21847..5ecbaef 100644
--- a/libavcodec/x86/pngdsp-init.c
+++ b/libavcodec/x86/pngdsp-init.c
@@ -23,8 +23,8 @@
 #include "libavutil/cpu.h"
 #include "libavcodec/pngdsp.h"
 
-void ff_add_png_paeth_prediction_mmx2 (uint8_t *dst, uint8_t *src,
-                                       uint8_t *top, int w, int bpp);
+void ff_add_png_paeth_prediction_mmxext(uint8_t *dst, uint8_t *src,
+                                        uint8_t *top, int w, int bpp);
 void ff_add_png_paeth_prediction_ssse3(uint8_t *dst, uint8_t *src,
                                        uint8_t *top, int w, int bpp);
 void ff_add_bytes_l2_mmx (uint8_t *dst, uint8_t *src1,
@@ -42,7 +42,7 @@ void ff_pngdsp_init_x86(PNGDSPContext *dsp)
         dsp->add_bytes_l2         = ff_add_bytes_l2_mmx;
 #endif
     if (flags & AV_CPU_FLAG_MMXEXT)
-        dsp->add_paeth_prediction = ff_add_png_paeth_prediction_mmx2;
+        dsp->add_paeth_prediction = ff_add_png_paeth_prediction_mmxext;
     if (flags & AV_CPU_FLAG_SSE2)
         dsp->add_bytes_l2         = ff_add_bytes_l2_sse2;
     if (flags & AV_CPU_FLAG_SSSE3)
diff --git a/libavcodec/x86/pngdsp.asm b/libavcodec/x86/pngdsp.asm
index d6e6374..8b4c42c 100644
--- a/libavcodec/x86/pngdsp.asm
+++ b/libavcodec/x86/pngdsp.asm
@@ -167,7 +167,7 @@ cglobal add_png_paeth_prediction, 5, 7, %1, dst, src, top, 
w, bpp, end, cntr
     RET
 %endmacro
 
-INIT_MMX mmx2
+INIT_MMX mmxext
 ADD_PAETH_PRED_FN 0
 
 INIT_MMX ssse3
diff --git a/libavcodec/x86/rv34dsp.asm b/libavcodec/x86/rv34dsp.asm
index c43b77a..d8ec368 100644
--- a/libavcodec/x86/rv34dsp.asm
+++ b/libavcodec/x86/rv34dsp.asm
@@ -58,7 +58,7 @@ cglobal rv34_idct_%1, 1, 2, 0
     REP_RET
 %endmacro
 
-INIT_MMX mmx2
+INIT_MMX mmxext
 %define IDCT_DC IDCT_DC_ROUND
 rv34_idct dc
 %define IDCT_DC IDCT_DC_NOROUND
@@ -134,7 +134,7 @@ cglobal rv34_idct_dc_add, 3, 3
     mova        mm5, [pd_512]           ; 0x200
 %endmacro
 
-; ff_rv34_idct_add_mmx2(uint8_t *dst, ptrdiff_t stride, DCTELEM *block);
+; ff_rv34_idct_add_mmxext(uint8_t *dst, ptrdiff_t stride, DCTELEM *block);
 %macro COL_TRANSFORM  4
     pshufw      mm3, %2, 0xDD        ; col. 1,3,1,3
     pshufw       %2, %2, 0x88        ; col. 0,2,0,2
@@ -155,7 +155,7 @@ cglobal rv34_idct_dc_add, 3, 3
     packuswb     %2, %2
     movd         %1, %2
 %endmacro
-INIT_MMX mmx2
+INIT_MMX mmxext
 cglobal rv34_idct_add, 3,3,0, d, s, b
     ROW_TRANSFORM       bq
     COL_TRANSFORM     [dq], mm0, [pw_col_coeffs+ 0], [pw_col_coeffs+ 8]
diff --git a/libavcodec/x86/rv34dsp_init.c b/libavcodec/x86/rv34dsp_init.c
index 7284a9b..8c43e3d 100644
--- a/libavcodec/x86/rv34dsp_init.c
+++ b/libavcodec/x86/rv34dsp_init.c
@@ -24,11 +24,11 @@
 #include "libavcodec/dsputil.h"
 #include "libavcodec/rv34dsp.h"
 
-void ff_rv34_idct_dc_mmx2(DCTELEM *block);
-void ff_rv34_idct_dc_noround_mmx2(DCTELEM *block);
+void ff_rv34_idct_dc_mmxext(DCTELEM *block);
+void ff_rv34_idct_dc_noround_mmxext(DCTELEM *block);
 void ff_rv34_idct_dc_add_mmx(uint8_t *dst, ptrdiff_t stride, int dc);
 void ff_rv34_idct_dc_add_sse4(uint8_t *dst, ptrdiff_t stride, int dc);
-void ff_rv34_idct_add_mmx2(uint8_t *dst, ptrdiff_t stride, DCTELEM *block);
+void ff_rv34_idct_add_mmxext(uint8_t *dst, ptrdiff_t stride, DCTELEM *block);
 
 av_cold void ff_rv34dsp_init_x86(RV34DSPContext* c, DSPContext *dsp)
 {
@@ -38,8 +38,8 @@ av_cold void ff_rv34dsp_init_x86(RV34DSPContext* c, 
DSPContext *dsp)
     if (mm_flags & AV_CPU_FLAG_MMX)
         c->rv34_idct_dc_add = ff_rv34_idct_dc_add_mmx;
     if (mm_flags & AV_CPU_FLAG_MMXEXT) {
-        c->rv34_inv_transform_dc = ff_rv34_idct_dc_noround_mmx2;
-        c->rv34_idct_add         = ff_rv34_idct_add_mmx2;
+        c->rv34_inv_transform_dc = ff_rv34_idct_dc_noround_mmxext;
+        c->rv34_idct_add         = ff_rv34_idct_add_mmxext;
     }
     if (mm_flags & AV_CPU_FLAG_SSE4)
         c->rv34_idct_dc_add = ff_rv34_idct_dc_add_sse4;
diff --git a/libavcodec/x86/rv40dsp.asm b/libavcodec/x86/rv40dsp.asm
index ae740c2..eb7fc9f 100644
--- a/libavcodec/x86/rv40dsp.asm
+++ b/libavcodec/x86/rv40dsp.asm
@@ -241,7 +241,7 @@ INIT_MMX  mmx
 FILTER_V  put
 FILTER_H  put
 
-INIT_MMX  mmx2
+INIT_MMX  mmxext
 FILTER_V  avg
 FILTER_H  avg
 
@@ -487,7 +487,7 @@ cglobal rv40_weight_func_%1_%2, 6, 7, 8
     REP_RET
 %endmacro
 
-INIT_MMX mmx2
+INIT_MMX mmxext
 RV40_WEIGHT   rnd,    8, 3
 RV40_WEIGHT   rnd,   16, 4
 RV40_WEIGHT   nornd,  8, 3
diff --git a/libavcodec/x86/rv40dsp_init.c b/libavcodec/x86/rv40dsp_init.c
index bee3365..daaa1a6 100644
--- a/libavcodec/x86/rv40dsp_init.c
+++ b/libavcodec/x86/rv40dsp_init.c
@@ -31,15 +31,15 @@
 
 void ff_put_rv40_chroma_mc8_mmx  (uint8_t *dst, uint8_t *src,
                                   int stride, int h, int x, int y);
-void ff_avg_rv40_chroma_mc8_mmx2 (uint8_t *dst, uint8_t *src,
-                                  int stride, int h, int x, int y);
+void ff_avg_rv40_chroma_mc8_mmxext(uint8_t *dst, uint8_t *src,
+                                   int stride, int h, int x, int y);
 void ff_avg_rv40_chroma_mc8_3dnow(uint8_t *dst, uint8_t *src,
                                   int stride, int h, int x, int y);
 
 void ff_put_rv40_chroma_mc4_mmx  (uint8_t *dst, uint8_t *src,
                                   int stride, int h, int x, int y);
-void ff_avg_rv40_chroma_mc4_mmx2 (uint8_t *dst, uint8_t *src,
-                                  int stride, int h, int x, int y);
+void ff_avg_rv40_chroma_mc4_mmxext(uint8_t *dst, uint8_t *src,
+                                   int stride, int h, int x, int y);
 void ff_avg_rv40_chroma_mc4_3dnow(uint8_t *dst, uint8_t *src,
                                   int stride, int h, int x, int y);
 
@@ -52,7 +52,7 @@ void ff_rv40_weight_func_nornd_16_##opt(uint8_t *dst, uint8_t 
*src1, uint8_t *sr
                                         int w1, int w2, ptrdiff_t stride); \
 void ff_rv40_weight_func_nornd_8_##opt (uint8_t *dst, uint8_t *src1, uint8_t 
*src2, \
                                         int w1, int w2, ptrdiff_t stride);
-DECLARE_WEIGHT(mmx2)
+DECLARE_WEIGHT(mmxext)
 DECLARE_WEIGHT(sse2)
 DECLARE_WEIGHT(ssse3)
 
@@ -147,9 +147,9 @@ QPEL_MC_DECL(avg_, _sse2)
 
 QPEL_MC_DECL(put_, _mmx)
 
-#define ff_put_rv40_qpel_h_mmx2  ff_put_rv40_qpel_h_mmx
-#define ff_put_rv40_qpel_v_mmx2  ff_put_rv40_qpel_v_mmx
-QPEL_MC_DECL(avg_, _mmx2)
+#define ff_put_rv40_qpel_h_mmxext  ff_put_rv40_qpel_h_mmx
+#define ff_put_rv40_qpel_v_mmxext  ff_put_rv40_qpel_v_mmx
+QPEL_MC_DECL(avg_, _mmxext)
 
 #define ff_put_rv40_qpel_h_3dnow  ff_put_rv40_qpel_h_mmx
 #define ff_put_rv40_qpel_v_3dnow  ff_put_rv40_qpel_v_mmx
@@ -201,14 +201,14 @@ void ff_rv40dsp_init_x86(RV34DSPContext *c, DSPContext 
*dsp)
 #endif
     }
     if (mm_flags & AV_CPU_FLAG_MMXEXT) {
-        c->avg_chroma_pixels_tab[0] = ff_avg_rv40_chroma_mc8_mmx2;
-        c->avg_chroma_pixels_tab[1] = ff_avg_rv40_chroma_mc4_mmx2;
-        c->rv40_weight_pixels_tab[0][0] = ff_rv40_weight_func_rnd_16_mmx2;
-        c->rv40_weight_pixels_tab[0][1] = ff_rv40_weight_func_rnd_8_mmx2;
-        c->rv40_weight_pixels_tab[1][0] = ff_rv40_weight_func_nornd_16_mmx2;
-        c->rv40_weight_pixels_tab[1][1] = ff_rv40_weight_func_nornd_8_mmx2;
+        c->avg_chroma_pixels_tab[0]     = ff_avg_rv40_chroma_mc8_mmxext;
+        c->avg_chroma_pixels_tab[1]     = ff_avg_rv40_chroma_mc4_mmxext;
+        c->rv40_weight_pixels_tab[0][0] = ff_rv40_weight_func_rnd_16_mmxext;
+        c->rv40_weight_pixels_tab[0][1] = ff_rv40_weight_func_rnd_8_mmxext;
+        c->rv40_weight_pixels_tab[1][0] = ff_rv40_weight_func_nornd_16_mmxext;
+        c->rv40_weight_pixels_tab[1][1] = ff_rv40_weight_func_nornd_8_mmxext;
 #if ARCH_X86_32
-        QPEL_MC_SET(avg_, _mmx2)
+        QPEL_MC_SET(avg_, _mmxext)
 #endif
     } else if (mm_flags & AV_CPU_FLAG_3DNOW) {
         c->avg_chroma_pixels_tab[0] = ff_avg_rv40_chroma_mc8_3dnow;
diff --git a/libavcodec/x86/vc1dsp_mmx.c b/libavcodec/x86/vc1dsp_mmx.c
index 05a8dd2..e5dc219 100644
--- a/libavcodec/x86/vc1dsp_mmx.c
+++ b/libavcodec/x86/vc1dsp_mmx.c
@@ -712,7 +712,7 @@ static void vc1_h_loop_filter16_ ## EXT(uint8_t *src, int 
stride, int pq) \
 }
 
 #if HAVE_YASM
-LOOP_FILTER(mmx2)
+LOOP_FILTER(mmxext)
 LOOP_FILTER(sse2)
 LOOP_FILTER(ssse3)
 
@@ -728,8 +728,8 @@ static void vc1_h_loop_filter16_sse4(uint8_t *src, int 
stride, int pq)
 
 void ff_put_vc1_chroma_mc8_mmx_nornd  (uint8_t *dst, uint8_t *src,
                                        int stride, int h, int x, int y);
-void ff_avg_vc1_chroma_mc8_mmx2_nornd (uint8_t *dst, uint8_t *src,
-                                       int stride, int h, int x, int y);
+void ff_avg_vc1_chroma_mc8_mmxext_nornd(uint8_t *dst, uint8_t *src,
+                                        int stride, int h, int x, int y);
 void ff_avg_vc1_chroma_mc8_3dnow_nornd(uint8_t *dst, uint8_t *src,
                                        int stride, int h, int x, int y);
 void ff_put_vc1_chroma_mc8_ssse3_nornd(uint8_t *dst, uint8_t *src,
@@ -806,8 +806,8 @@ void ff_vc1dsp_init_mmx(VC1DSPContext *dsp)
     }
 
     if (mm_flags & AV_CPU_FLAG_MMXEXT) {
-        ASSIGN_LF(mmx2);
-        dsp->avg_no_rnd_vc1_chroma_pixels_tab[0]= 
ff_avg_vc1_chroma_mc8_mmx2_nornd;
+        ASSIGN_LF(mmxext);
+        dsp->avg_no_rnd_vc1_chroma_pixels_tab[0] = 
ff_avg_vc1_chroma_mc8_mmxext_nornd;
     } else if (mm_flags & AV_CPU_FLAG_3DNOW) {
         dsp->avg_no_rnd_vc1_chroma_pixels_tab[0]= 
ff_avg_vc1_chroma_mc8_3dnow_nornd;
     }
diff --git a/libavcodec/x86/vp3dsp.asm b/libavcodec/x86/vp3dsp.asm
index 7a88892..ebe763f 100644
--- a/libavcodec/x86/vp3dsp.asm
+++ b/libavcodec/x86/vp3dsp.asm
@@ -102,7 +102,7 @@ SECTION .text
     mov  [r0+r3  -1], r2w
 %endmacro
 
-INIT_MMX mmx2
+INIT_MMX mmxext
 cglobal vp3_v_loop_filter, 3, 4
 %if ARCH_X86_64
     movsxd        r1, r1d
@@ -634,7 +634,7 @@ vp3_idct_funcs
     movq   [r0+r3  ], m5
 %endmacro
 
-INIT_MMX mmx2
+INIT_MMX mmxext
 cglobal vp3_idct_dc_add, 3, 4
 %if ARCH_X86_64
     movsxd        r1, r1d
diff --git a/libavcodec/x86/vp3dsp_init.c b/libavcodec/x86/vp3dsp_init.c
index 45af041..91ac777 100644
--- a/libavcodec/x86/vp3dsp_init.c
+++ b/libavcodec/x86/vp3dsp_init.c
@@ -30,11 +30,13 @@ void ff_vp3_idct_add_mmx(uint8_t *dest, int line_size, 
DCTELEM *block);
 void ff_vp3_idct_put_sse2(uint8_t *dest, int line_size, DCTELEM *block);
 void ff_vp3_idct_add_sse2(uint8_t *dest, int line_size, DCTELEM *block);
 
-void ff_vp3_idct_dc_add_mmx2(uint8_t *dest, int line_size,
-                             const DCTELEM *block);
+void ff_vp3_idct_dc_add_mmxext(uint8_t *dest, int line_size,
+                               const DCTELEM *block);
 
-void ff_vp3_v_loop_filter_mmx2(uint8_t *src, int stride, int *bounding_values);
-void ff_vp3_h_loop_filter_mmx2(uint8_t *src, int stride, int *bounding_values);
+void ff_vp3_v_loop_filter_mmxext(uint8_t *src, int stride,
+                                 int *bounding_values);
+void ff_vp3_h_loop_filter_mmxext(uint8_t *src, int stride,
+                                 int *bounding_values);
 
 av_cold void ff_vp3dsp_init_x86(VP3DSPContext *c, int flags)
 {
@@ -50,11 +52,11 @@ av_cold void ff_vp3dsp_init_x86(VP3DSPContext *c, int flags)
 #endif
 
     if (HAVE_MMXEXT && cpuflags & AV_CPU_FLAG_MMXEXT) {
-        c->idct_dc_add = ff_vp3_idct_dc_add_mmx2;
+        c->idct_dc_add = ff_vp3_idct_dc_add_mmxext;
 
         if (!(flags & CODEC_FLAG_BITEXACT)) {
-            c->v_loop_filter = ff_vp3_v_loop_filter_mmx2;
-            c->h_loop_filter = ff_vp3_h_loop_filter_mmx2;
+            c->v_loop_filter = ff_vp3_v_loop_filter_mmxext;
+            c->h_loop_filter = ff_vp3_h_loop_filter_mmxext;
         }
     }
 
diff --git a/libavcodec/x86/vp8dsp-init.c b/libavcodec/x86/vp8dsp-init.c
index 64dd8ce..4db1bd3 100644
--- a/libavcodec/x86/vp8dsp-init.c
+++ b/libavcodec/x86/vp8dsp-init.c
@@ -29,16 +29,16 @@
 /*
  * MC functions
  */
-extern void ff_put_vp8_epel4_h4_mmx2  (uint8_t *dst, ptrdiff_t dststride,
+extern void ff_put_vp8_epel4_h4_mmxext(uint8_t *dst, ptrdiff_t dststride,
                                        uint8_t *src, ptrdiff_t srcstride,
                                        int height, int mx, int my);
-extern void ff_put_vp8_epel4_h6_mmx2  (uint8_t *dst, ptrdiff_t dststride,
+extern void ff_put_vp8_epel4_h6_mmxext(uint8_t *dst, ptrdiff_t dststride,
                                        uint8_t *src, ptrdiff_t srcstride,
                                        int height, int mx, int my);
-extern void ff_put_vp8_epel4_v4_mmx2  (uint8_t *dst, ptrdiff_t dststride,
+extern void ff_put_vp8_epel4_v4_mmxext(uint8_t *dst, ptrdiff_t dststride,
                                        uint8_t *src, ptrdiff_t srcstride,
                                        int height, int mx, int my);
-extern void ff_put_vp8_epel4_v6_mmx2  (uint8_t *dst, ptrdiff_t dststride,
+extern void ff_put_vp8_epel4_v6_mmxext(uint8_t *dst, ptrdiff_t dststride,
                                        uint8_t *src, ptrdiff_t srcstride,
                                        int height, int mx, int my);
 
@@ -80,7 +80,7 @@ extern void ff_put_vp8_epel8_v6_ssse3 (uint8_t *dst, 
ptrdiff_t dststride,
                                        uint8_t *src, ptrdiff_t srcstride,
                                        int height, int mx, int my);
 
-extern void ff_put_vp8_bilinear4_h_mmx2  (uint8_t *dst, ptrdiff_t dststride,
+extern void ff_put_vp8_bilinear4_h_mmxext(uint8_t *dst, ptrdiff_t dststride,
                                           uint8_t *src, ptrdiff_t srcstride,
                                           int height, int mx, int my);
 extern void ff_put_vp8_bilinear8_h_sse2  (uint8_t *dst, ptrdiff_t dststride,
@@ -93,7 +93,7 @@ extern void ff_put_vp8_bilinear8_h_ssse3 (uint8_t *dst, 
ptrdiff_t dststride,
                                           uint8_t *src, ptrdiff_t srcstride,
                                           int height, int mx, int my);
 
-extern void ff_put_vp8_bilinear4_v_mmx2  (uint8_t *dst, ptrdiff_t dststride,
+extern void ff_put_vp8_bilinear4_v_mmxext(uint8_t *dst, ptrdiff_t dststride,
                                           uint8_t *src, ptrdiff_t srcstride,
                                           int height, int mx, int my);
 extern void ff_put_vp8_bilinear8_v_sse2  (uint8_t *dst, ptrdiff_t dststride,
@@ -139,16 +139,16 @@ static void ff_put_vp8_ ## FILTERTYPE ## 8_ ## TAPTYPE ## 
_ ## OPT( \
 }
 
 #if ARCH_X86_32
-TAP_W8 (mmx2,  epel, h4)
-TAP_W8 (mmx2,  epel, h6)
-TAP_W16(mmx2,  epel, h6)
-TAP_W8 (mmx2,  epel, v4)
-TAP_W8 (mmx2,  epel, v6)
-TAP_W16(mmx2,  epel, v6)
-TAP_W8 (mmx2,  bilinear, h)
-TAP_W16(mmx2,  bilinear, h)
-TAP_W8 (mmx2,  bilinear, v)
-TAP_W16(mmx2,  bilinear, v)
+TAP_W8 (mmxext, epel, h4)
+TAP_W8 (mmxext, epel, h6)
+TAP_W16(mmxext, epel, h6)
+TAP_W8 (mmxext, epel, v4)
+TAP_W8 (mmxext, epel, v6)
+TAP_W16(mmxext, epel, v6)
+TAP_W8 (mmxext, bilinear, h)
+TAP_W16(mmxext, bilinear, h)
+TAP_W8 (mmxext, bilinear, v)
+TAP_W16(mmxext, bilinear, v)
 #endif
 
 TAP_W16(sse2,  epel, h6)
@@ -177,13 +177,13 @@ static void ff_put_vp8_epel ## SIZE ## _h ## TAPNUMX ## v 
## TAPNUMY ## _ ## OPT
 
 #if ARCH_X86_32
 #define HVTAPMMX(x, y) \
-HVTAP(mmx2, 8, x, y,  4,  8) \
-HVTAP(mmx2, 8, x, y,  8, 16)
+HVTAP(mmxext, 8, x, y,  4,  8) \
+HVTAP(mmxext, 8, x, y,  8, 16)
 
-HVTAP(mmx2, 8, 6, 6, 16, 16)
+HVTAP(mmxext, 8, 6, 6, 16, 16)
 #else
 #define HVTAPMMX(x, y) \
-HVTAP(mmx2, 8, x, y,  4,  8)
+HVTAP(mmxext, 8, x, y,  4,  8)
 #endif
 
 HVTAPMMX(4, 4)
@@ -218,10 +218,10 @@ static void ff_put_vp8_bilinear ## SIZE ## _hv_ ## OPT( \
         dst, dststride, tmp, SIZE,      height,     mx, my); \
 }
 
-HVBILIN(mmx2,  8,  4,  8)
+HVBILIN(mmxext,  8,  4,  8)
 #if ARCH_X86_32
-HVBILIN(mmx2,  8,  8, 16)
-HVBILIN(mmx2,  8, 16, 16)
+HVBILIN(mmxext,  8,  8, 16)
+HVBILIN(mmxext,  8, 16, 16)
 #endif
 HVBILIN(sse2,  8,  8, 16)
 HVBILIN(sse2,  8, 16, 16)
@@ -283,7 +283,7 @@ extern void ff_vp8_h_loop_filter8uv_mbedge_ ## NAME(uint8_t 
*dstU, \
                                                     int e, int i, int hvt);
 
 DECLARE_LOOP_FILTER(mmx)
-DECLARE_LOOP_FILTER(mmx2)
+DECLARE_LOOP_FILTER(mmxext)
 DECLARE_LOOP_FILTER(sse2)
 DECLARE_LOOP_FILTER(ssse3)
 DECLARE_LOOP_FILTER(sse4)
@@ -351,26 +351,26 @@ av_cold void ff_vp8dsp_init_x86(VP8DSPContext* c)
     /* note that 4-tap width=16 functions are missing because w=16
      * is only used for luma, and luma is always a copy or sixtap. */
     if (mm_flags & AV_CPU_FLAG_MMXEXT) {
-        VP8_MC_FUNC(2, 4, mmx2);
-        VP8_BILINEAR_MC_FUNC(2, 4, mmx2);
+        VP8_MC_FUNC(2, 4, mmxext);
+        VP8_BILINEAR_MC_FUNC(2, 4, mmxext);
 #if ARCH_X86_32
-        VP8_LUMA_MC_FUNC(0, 16, mmx2);
-        VP8_MC_FUNC(1, 8, mmx2);
-        VP8_BILINEAR_MC_FUNC(0, 16, mmx2);
-        VP8_BILINEAR_MC_FUNC(1, 8, mmx2);
-
-        c->vp8_v_loop_filter_simple = ff_vp8_v_loop_filter_simple_mmx2;
-        c->vp8_h_loop_filter_simple = ff_vp8_h_loop_filter_simple_mmx2;
-
-        c->vp8_v_loop_filter16y_inner = ff_vp8_v_loop_filter16y_inner_mmx2;
-        c->vp8_h_loop_filter16y_inner = ff_vp8_h_loop_filter16y_inner_mmx2;
-        c->vp8_v_loop_filter8uv_inner = ff_vp8_v_loop_filter8uv_inner_mmx2;
-        c->vp8_h_loop_filter8uv_inner = ff_vp8_h_loop_filter8uv_inner_mmx2;
-
-        c->vp8_v_loop_filter16y       = ff_vp8_v_loop_filter16y_mbedge_mmx2;
-        c->vp8_h_loop_filter16y       = ff_vp8_h_loop_filter16y_mbedge_mmx2;
-        c->vp8_v_loop_filter8uv       = ff_vp8_v_loop_filter8uv_mbedge_mmx2;
-        c->vp8_h_loop_filter8uv       = ff_vp8_h_loop_filter8uv_mbedge_mmx2;
+        VP8_LUMA_MC_FUNC(0, 16, mmxext);
+        VP8_MC_FUNC(1, 8, mmxext);
+        VP8_BILINEAR_MC_FUNC(0, 16, mmxext);
+        VP8_BILINEAR_MC_FUNC(1, 8, mmxext);
+
+        c->vp8_v_loop_filter_simple   = ff_vp8_v_loop_filter_simple_mmxext;
+        c->vp8_h_loop_filter_simple   = ff_vp8_h_loop_filter_simple_mmxext;
+
+        c->vp8_v_loop_filter16y_inner = ff_vp8_v_loop_filter16y_inner_mmxext;
+        c->vp8_h_loop_filter16y_inner = ff_vp8_h_loop_filter16y_inner_mmxext;
+        c->vp8_v_loop_filter8uv_inner = ff_vp8_v_loop_filter8uv_inner_mmxext;
+        c->vp8_h_loop_filter8uv_inner = ff_vp8_h_loop_filter8uv_inner_mmxext;
+
+        c->vp8_v_loop_filter16y       = ff_vp8_v_loop_filter16y_mbedge_mmxext;
+        c->vp8_h_loop_filter16y       = ff_vp8_h_loop_filter16y_mbedge_mmxext;
+        c->vp8_v_loop_filter8uv       = ff_vp8_v_loop_filter8uv_mbedge_mmxext;
+        c->vp8_h_loop_filter8uv       = ff_vp8_h_loop_filter8uv_mbedge_mmxext;
 #endif
     }
 
diff --git a/libavcodec/x86/vp8dsp.asm b/libavcodec/x86/vp8dsp.asm
index 531b205..3b5fd18 100644
--- a/libavcodec/x86/vp8dsp.asm
+++ b/libavcodec/x86/vp8dsp.asm
@@ -339,7 +339,7 @@ INIT_XMM ssse3
 FILTER_SSSE3 8
 
 ; 4x4 block, H-only 4-tap filter
-INIT_MMX mmx2
+INIT_MMX mmxext
 cglobal put_vp8_epel4_h4, 6, 6 + npicregs, 0, dst, dststride, src, srcstride, 
height, mx, picreg
     shl       mxd, 4
 %ifdef PIC
@@ -387,7 +387,7 @@ cglobal put_vp8_epel4_h4, 6, 6 + npicregs, 0, dst, 
dststride, src, srcstride, he
     REP_RET
 
 ; 4x4 block, H-only 6-tap filter
-INIT_MMX mmx2
+INIT_MMX mmxext
 cglobal put_vp8_epel4_h6, 6, 6 + npicregs, 0, dst, dststride, src, srcstride, 
height, mx, picreg
     lea       mxd, [mxq*3]
 %ifdef PIC
@@ -674,7 +674,7 @@ cglobal put_vp8_epel%1_v6, 7, 7, 8, dst, dststride, src, 
srcstride, height, picr
     REP_RET
 %endmacro
 
-INIT_MMX mmx2
+INIT_MMX mmxext
 FILTER_V 4
 INIT_XMM sse2
 FILTER_V 8
@@ -770,7 +770,7 @@ cglobal put_vp8_bilinear%1_h, 6, 6 + npicregs, 7, dst, 
dststride, src, srcstride
     REP_RET
 %endmacro
 
-INIT_MMX mmx2
+INIT_MMX mmxext
 FILTER_BILINEAR 4
 INIT_XMM sse2
 FILTER_BILINEAR 8
@@ -1612,7 +1612,7 @@ cglobal vp8_%1_loop_filter_simple, 3, %2, 8, dst, stride, 
flim, cntr
 INIT_MMX mmx
 SIMPLE_LOOPFILTER v, 4
 SIMPLE_LOOPFILTER h, 5
-INIT_MMX mmx2
+INIT_MMX mmxext
 SIMPLE_LOOPFILTER v, 4
 SIMPLE_LOOPFILTER h, 5
 %endif
@@ -1836,7 +1836,7 @@ cglobal vp8_%1_loop_filter16y_inner, 5, 5, 13, dst, 
stride, flimE, flimI, hevthr
     psubusb          m6, m5          ; q2-q1
     por              m6, m4          ; abs(q2-q1)
 
-%if notcpuflag(mmx2)
+%if notcpuflag(mmxext)
     mova             m4, m_flimI
     pxor             m3, m3
     psubusb          m0, m4
@@ -1876,7 +1876,7 @@ cglobal vp8_%1_loop_filter16y_inner, 5, 5, 13, dst, 
stride, flimE, flimI, hevthr
     psubusb          m1, m3          ; p1-p0
     psubusb          m6, m2          ; p0-p1
     por              m1, m6          ; abs(p1-p0)
-%if notcpuflag(mmx2)
+%if notcpuflag(mmxext)
     mova             m6, m1
     psubusb          m1, m4
     psubusb          m6, m_hevthr
@@ -1907,7 +1907,7 @@ cglobal vp8_%1_loop_filter16y_inner, 5, 5, 13, dst, 
stride, flimE, flimI, hevthr
     psubusb          m1, m5          ; q0-q1
     psubusb          m7, m4          ; q1-q0
     por              m1, m7          ; abs(q1-q0)
-%if notcpuflag(mmx2)
+%if notcpuflag(mmxext)
     mova             m7, m1
     psubusb          m1, m6
     psubusb          m7, m_hevthr
@@ -2015,14 +2015,14 @@ cglobal vp8_%1_loop_filter16y_inner, 5, 5, 13, dst, 
stride, flimE, flimI, hevthr
 %else
     mova             m6, m_maskres
 %endif
-%if notcpuflag(mmx2)
+%if notcpuflag(mmxext)
     mova             m7, [pb_1]
 %else ; mmxext/sse2
     pxor             m7, m7
 %endif
     pand             m0, m6
     pand             m1, m6
-%if notcpuflag(mmx2)
+%if notcpuflag(mmxext)
     paddusb          m0, m7
     pand             m1, [pb_FE]
     pandn            m7, m0
@@ -2098,7 +2098,7 @@ INNER_LOOPFILTER h, 16
 INNER_LOOPFILTER v,  8
 INNER_LOOPFILTER h,  8
 
-INIT_MMX mmx2
+INIT_MMX mmxext
 INNER_LOOPFILTER v, 16
 INNER_LOOPFILTER h, 16
 INNER_LOOPFILTER v,  8
@@ -2344,7 +2344,7 @@ cglobal vp8_%1_loop_filter16y_mbedge, 5, 5, 15, dst1, 
stride, flimE, flimI, hevt
     psubusb          m6, m5          ; q2-q1
     por              m6, m4          ; abs(q2-q1)
 
-%if notcpuflag(mmx2)
+%if notcpuflag(mmxext)
     mova             m4, m_flimI
     pxor             m3, m3
     psubusb          m0, m4
@@ -2384,7 +2384,7 @@ cglobal vp8_%1_loop_filter16y_mbedge, 5, 5, 15, dst1, 
stride, flimE, flimI, hevt
     psubusb          m1, m3          ; p1-p0
     psubusb          m6, m2          ; p0-p1
     por              m1, m6          ; abs(p1-p0)
-%if notcpuflag(mmx2)
+%if notcpuflag(mmxext)
     mova             m6, m1
     psubusb          m1, m4
     psubusb          m6, m_hevthr
@@ -2415,7 +2415,7 @@ cglobal vp8_%1_loop_filter16y_mbedge, 5, 5, 15, dst1, 
stride, flimE, flimI, hevt
     psubusb          m1, m5          ; q0-q1
     psubusb          m7, m4          ; q1-q0
     por              m1, m7          ; abs(q1-q0)
-%if notcpuflag(mmx2)
+%if notcpuflag(mmxext)
     mova             m7, m1
     psubusb          m1, m6
     psubusb          m7, m_hevthr
@@ -2756,7 +2756,7 @@ MBEDGE_LOOPFILTER h, 16
 MBEDGE_LOOPFILTER v,  8
 MBEDGE_LOOPFILTER h,  8
 
-INIT_MMX mmx2
+INIT_MMX mmxext
 MBEDGE_LOOPFILTER v, 16
 MBEDGE_LOOPFILTER h, 16
 MBEDGE_LOOPFILTER v,  8
diff --git a/libavutil/x86/x86inc.asm b/libavutil/x86/x86inc.asm
index 03e6c07..9dbd9b0 100644
--- a/libavutil/x86/x86inc.asm
+++ b/libavutil/x86/x86inc.asm
@@ -555,10 +555,10 @@ SECTION .note.GNU-stack noalloc noexec nowrite progbits
 ; cpuflags
 
 %assign cpuflags_mmx      (1<<0)
-%assign cpuflags_mmx2     (1<<1) | cpuflags_mmx
+%assign cpuflags_mmxext   (1<<1) | cpuflags_mmx
 %assign cpuflags_3dnow    (1<<2) | cpuflags_mmx
 %assign cpuflags_3dnowext (1<<3) | cpuflags_3dnow
-%assign cpuflags_sse      (1<<4) | cpuflags_mmx2
+%assign cpuflags_sse      (1<<4) | cpuflags_mmxext
 %assign cpuflags_sse2     (1<<5) | cpuflags_sse
 %assign cpuflags_sse2slow (1<<6) | cpuflags_sse2
 %assign cpuflags_sse3     (1<<7) | cpuflags_sse2
@@ -611,7 +611,7 @@ SECTION .note.GNU-stack noalloc noexec nowrite progbits
         %elifidn %1, sse3
             %define movu lddqu
         %endif
-        %if notcpuflag(mmx2)
+        %if notcpuflag(mmxext)
             CPU basicnop
         %endif
     %else
diff --git a/libavutil/x86/x86util.asm b/libavutil/x86/x86util.asm
index 4c80809..1125e09 100644
--- a/libavutil/x86/x86util.asm
+++ b/libavutil/x86/x86util.asm
@@ -540,7 +540,7 @@
 %if mmsize == 16
     pshuflw    %1, %2, (%3)*0x55
     punpcklqdq %1, %1
-%elif cpuflag(mmx2)
+%elif cpuflag(mmxext)
     pshufw     %1, %2, (%3)*0x55
 %else
     %ifnidn %1, %2
diff --git a/libswscale/x86/output.asm b/libswscale/x86/output.asm
index 1c68113..2aac55d 100644
--- a/libswscale/x86/output.asm
+++ b/libswscale/x86/output.asm
@@ -249,7 +249,7 @@ cglobal yuv2planeX_%1, %3, 8, %2, filter, fltsize, src, 
dst, w, dither, offset
 
 %define PALIGNR PALIGNR_MMX
 %if ARCH_X86_32
-INIT_MMX mmx2
+INIT_MMX mmxext
 yuv2planeX_fn  8,  0, 7
 yuv2planeX_fn  9,  0, 5
 yuv2planeX_fn 10,  0, 5
@@ -391,7 +391,7 @@ INIT_MMX mmx
 yuv2plane1_fn  8, 0, 5
 yuv2plane1_fn 16, 0, 3
 
-INIT_MMX mmx2
+INIT_MMX mmxext
 yuv2plane1_fn  9, 0, 3
 yuv2plane1_fn 10, 0, 3
 %endif
diff --git a/libswscale/x86/swscale.c b/libswscale/x86/swscale.c
index 5ed76f5..767b39d 100644
--- a/libswscale/x86/swscale.c
+++ b/libswscale/x86/swscale.c
@@ -249,7 +249,7 @@ extern void ff_yuv2planeX_ ## size ## _ ## opt(const 
int16_t *filter, int filter
     VSCALEX_FUNC(10, opt)
 
 #if ARCH_X86_32
-VSCALEX_FUNCS(mmx2);
+VSCALEX_FUNCS(mmxext);
 #endif
 VSCALEX_FUNCS(sse2);
 VSCALEX_FUNCS(sse4);
@@ -266,7 +266,7 @@ extern void ff_yuv2plane1_ ## size ## _ ## opt(const 
int16_t *src, uint8_t *dst,
     VSCALE_FUNC(16, opt1)
 
 #if ARCH_X86_32
-VSCALE_FUNCS(mmx, mmx2);
+VSCALE_FUNCS(mmx, mmxext);
 #endif
 VSCALE_FUNCS(sse2, sse2);
 VSCALE_FUNC(16, sse4);
@@ -360,7 +360,7 @@ switch(c->dstBpc){ \
     if (cpu_flags & AV_CPU_FLAG_MMX) {
         ASSIGN_MMX_SCALE_FUNC(c->hyScale, c->hLumFilterSize, mmx, mmx);
         ASSIGN_MMX_SCALE_FUNC(c->hcScale, c->hChrFilterSize, mmx, mmx);
-        ASSIGN_VSCALE_FUNC(c->yuv2plane1, mmx, mmx2, cpu_flags & 
AV_CPU_FLAG_MMXEXT);
+        ASSIGN_VSCALE_FUNC(c->yuv2plane1, mmx, mmxext, cpu_flags & 
AV_CPU_FLAG_MMXEXT);
 
         switch (c->srcFormat) {
         case PIX_FMT_Y400A:
@@ -393,7 +393,7 @@ switch(c->dstBpc){ \
         }
     }
     if (cpu_flags & AV_CPU_FLAG_MMXEXT) {
-        ASSIGN_VSCALEX_FUNC(c->yuv2planeX, mmx2, , 1);
+        ASSIGN_VSCALEX_FUNC(c->yuv2planeX, mmxext, , 1);
     }
 #endif
 #define ASSIGN_SSE_SCALE_FUNC(hscalefn, filtersize, opt1, opt2) \
diff --git a/libavcodec/x86/vc1dsp_yasm.asm b/libavcodec/x86/vc1dsp_yasm.asm
index d78e1b5..adfb977 100644
--- a/libavcodec/x86/vc1dsp_yasm.asm
+++ b/libavcodec/x86/vc1dsp_yasm.asm
@@ -239,19 +239,19 @@ cglobal vc1_h_loop_filter_internal_%1
     VC1_H_LOOP_FILTER 4, r4
     ret
 
 ; void ff_vc1_v_loop_filter4_mmx2(uint8_t *src, int stride, int pq)
 cglobal vc1_v_loop_filter4_%1, 3,5,0
     START_V_FILTER
     call vc1_v_loop_filter_internal_%1
     RET
 
 ; void ff_vc1_h_loop_filter4_mmx2(uint8_t *src, int stride, int pq)
 cglobal vc1_h_loop_filter4_%1, 3,5,0
     START_H_FILTER 4
     call vc1_h_loop_filter_internal_%1
     RET
 
 ; void ff_vc1_v_loop_filter8_mmx2(uint8_t *src, int stride, int pq)
 cglobal vc1_v_loop_filter8_%1, 3,5,0
     START_V_FILTER
     call vc1_v_loop_filter_internal_%1
@@ -260,7 +260,7 @@ cglobal vc1_v_loop_filter8_%1, 3,5,0
     call vc1_v_loop_filter_internal_%1
     RET
 
 ; void ff_vc1_h_loop_filter8_mmx2(uint8_t *src, int stride, int pq)
 cglobal vc1_h_loop_filter8_%1, 3,5,0
     START_H_FILTER 4
     call vc1_h_loop_filter_internal_%1
@@ -270,7 +270,7 @@ cglobal vc1_h_loop_filter8_%1, 3,5,0
 %endmacro
 
 %define PABSW PABSW_MMXEXT
-VC1_LF_MMX mmx2
+VC1_LF_MMX mmxext
 
 INIT_XMM
 ; void ff_vc1_v_loop_filter8_sse2(uint8_t *src, int stride, int pq)
@@ -239,19 +239,19 @@ cglobal vc1_h_loop_filter_internal_%1
     ret
 
-; void ff_vc1_v_loop_filter4_mmx2(uint8_t *src, int stride, int pq)
+; void ff_vc1_v_loop_filter4_mmxext(uint8_t *src, int stride, int pq)
 cglobal vc1_v_loop_filter4_%1, 3,5,0
     START_V_FILTER
@@ -239,19 +239,19 @@ cglobal vc1_h_loop_filter_internal_%1
     RET
 
-; void ff_vc1_h_loop_filter4_mmx2(uint8_t *src, int stride, int pq)
+; void ff_vc1_h_loop_filter4_mmxext(uint8_t *src, int stride, int pq)
 cglobal vc1_h_loop_filter4_%1, 3,5,0
     START_H_FILTER 4
@@ -239,19 +239,19 @@ cglobal vc1_h_loop_filter_internal_%1
     RET
 
-; void ff_vc1_v_loop_filter8_mmx2(uint8_t *src, int stride, int pq)
+; void ff_vc1_v_loop_filter8_mmxext(uint8_t *src, int stride, int pq)
 cglobal vc1_v_loop_filter8_%1, 3,5,0
     START_V_FILTER
@@ -260,7 +260,7 @@ cglobal vc1_v_loop_filter8_%1, 3,5,0
     RET
 
-; void ff_vc1_h_loop_filter8_mmx2(uint8_t *src, int stride, int pq)
+; void ff_vc1_h_loop_filter8_mmxext(uint8_t *src, int stride, int pq)
 cglobal vc1_h_loop_filter8_%1, 3,5,0
     START_H_FILTER 4
-- 
1.7.2.5

_______________________________________________
libav-devel mailing list
[email protected]
https://lists.libav.org/mailman/listinfo/libav-devel

Reply via email to